@@ -74,7 +74,7 @@ Metagenome assembly, binning, and annotation:
         annotate  - Annotate MAGs using EggNOG and GTBD-tk
         diversity - Perform strain diversity analysis of MAGs using Lorikeet
         complete  - Runs each stage of the pipeline: assemble, recover, 
-                    annotate, genotype in that order.
+                    annotate, diversity in that order.
         cluster   - Combines and dereplicates the MAGs from multiple Aviary runs
                     using Galah
         batch     - Run Aviary using a given workflow on a supplied batch of samples
@@ -460,7 +460,7 @@ def main():
     )
 
     binning_group.add_argument(
-        '--skip-binners', '--skip_binners',
+        '--skip-binners', '--skip_binners', '--skip_binner', '--skip-binner',
         help='Optional list of binning algorithms to skip. Can be any combination of: \n'
              'rosella, semibin, metabat1, metabat2, metabat, vamb, concoct, maxbin2, maxbin \n'
              'Capitals will be auto-corrected. N.B. specifying "metabat" will skip both \n'
@@ -527,7 +527,7 @@ def main():
         '--ani',
         help='Overall ANI level to dereplicate at with FastANI.',
         dest='ani',
-        default=99
+        default=97
     )
 
     cluster_group.add_argument(
@@ -913,6 +913,14 @@ def main():
         required=True,
     )
 
+    batch_options.add_argument(
+        '--write-script', '--write_script',
+        help='Write the aviary batch Snakemake commands to a bash script and exit. \n'
+             'Useful when submitting jobs to HPC cluster with custom queueing.',
+        dest='write_script',
+        required=False
+    )
+
     batch_options.add_argument(
         '--cluster',
         help='Cluster final output of all samples using aviary cluster if possible.',
@@ -923,6 +931,14 @@ def main():
         default=True
     )
 
+    batch_options.add_argument(
+        '--cluster-ani-values', '--cluster_ani_values', '--ani-values', '--ani_values',
+        help='The range of ANI values to perform clustering and dereplication at during aviary cluster.',
+        dest='ani_values',
+        nargs='*',
+        default=[0.99, 0.97, 0.95]
+    )
+
     batch_options.add_argument(
         '--min-percent-read-identity-long', '--min_percent_read_identity_long',
         help='Minimum percent read identity used by CoverM for long-reads'
